package com.cultural.heritage.controller.address;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.dto.CommonRequest;
import com.cultural.heritage.model.dto.contacts.ContactsAddRequest;
import com.cultural.heritage.model.dto.contacts.ContactsUpdateRequest;
import com.cultural.heritage.model.entity.Contacts;
import com.cultural.heritage.service.address.ContactsService;
import com.obs.services.internal.utils.RestUtils;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.models.info.Contact;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/contacts")
@Slf4j
@Tag(name = "联系人接口")
public class ContactsController {


    @Resource
    private ContactsService contactsService;


    /**
     * 添加联系人
     * @param contactsAddRequest 联系人添加请求体
     * @return 是否添加成功
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addContacts(@RequestBody ContactsAddRequest contactsAddRequest) {
        if (contactsAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Contacts contacts = new Contacts();
        BeanUtils.copyProperties(contactsAddRequest, contacts);
        contactsService.verifyIsDefault(contacts);
        boolean result = contactsService.save(contacts);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



    /**
     * 更新联系人
     * @param contactsUpdateRequest  联系人更新请求体
     * @return  是否更新成功
     */
    @PostMapping("/update")
    public BaseResponse<Boolean> updateContacts(@RequestBody ContactsUpdateRequest contactsUpdateRequest) {
        if (contactsUpdateRequest == null || contactsUpdateRequest.getId() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Contacts contacts = new Contacts();
        BeanUtils.copyProperties(contactsUpdateRequest, contacts);
        contactsService.verifyIsDefault(contacts);
        boolean result = contactsService.updateById(contacts);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }




    /**
     * 删除联系人
     * @param contactsDeleteRequest  联系人删除请求体
     * @return 是否删除成功
     */
    @PostMapping("/delete")
    public BaseResponse<Boolean> deleteContacts(@RequestBody CommonRequest contactsDeleteRequest) {
        if (contactsDeleteRequest == null || contactsDeleteRequest.getId() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = contactsDeleteRequest.getId();
        boolean result = contactsService.removeById(id);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



    /**
     * 查询用户联系人信息
     * @param contactsQueryRequest  联系人查询请求体
     * @return  用户联系人列表
     */
    @PostMapping("/list")
    public BaseResponse<List<Contacts>> listUserContacts(@RequestBody CommonRequest contactsQueryRequest) {
        if (contactsQueryRequest == null || contactsQueryRequest.getId() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = contactsQueryRequest.getId();
        List<Contacts> list = contactsService.getUserAddressById(id);
        return ResultUtils.success(list);
    }







}
