package com.cultural.heritage.service.order.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.CommonConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.mapper.OrderMapper;
import com.cultural.heritage.model.dto.order.OrderQueryRequest;
import com.cultural.heritage.model.entity.Order;
import com.cultural.heritage.service.order.OrderService;
import com.cultural.heritage.utils.SqlUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class OrderServiceImpl extends ServiceImpl<OrderMapper, Order> implements OrderService {


    /**
     * 获取查询条件
     */
    @Override
    public QueryWrapper<Order> getQueryWrapper(OrderQueryRequest orderQueryRequest) {
        if (orderQueryRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long userId = orderQueryRequest.getUserId();
        Double minTotalAmount = orderQueryRequest.getMinTotalAmount();
        Double maxTotalAmount = orderQueryRequest.getMaxTotalAmount();
        String orderStatus = orderQueryRequest.getOrderStatus();
        String orderNumber = orderQueryRequest.getOrderNumber();
        Date startTime = orderQueryRequest.getStartTime();
        Date endTime = orderQueryRequest.getEndTime();
        String sortOrder = orderQueryRequest.getSortOrder();
        String sortField = orderQueryRequest.getSortField();

        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ObjectUtils.isNotEmpty(userId), "userId", userId);
        queryWrapper.ge(ObjectUtils.isNotEmpty(minTotalAmount), "totalAmount", minTotalAmount);
        queryWrapper.le(ObjectUtils.isNotEmpty(maxTotalAmount), "totalAmount", maxTotalAmount);
        queryWrapper.eq(StringUtils.isNotBlank(orderStatus), "orderStatus", orderStatus);
        queryWrapper.between("createTime", startTime, endTime);
        queryWrapper.eq(StringUtils.isNotBlank(orderNumber), "orderNumber", orderNumber);
        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
                sortField);
        return queryWrapper;
    }
}
